This is a code to perform retrievals on spectra of substellar objects using 
SNPE-C (citation) and neural spline flows (citation).

- Known issues:
    - installing sbi needs blas first
        - conda install blas works, but goes down to python 3.9.22